==> economynlp-0.0.4.tar.gz: economynlp-0.0.4/README.md <==
# Python Narrative packages

<img src="https://raw.githubusercontent.com/
python-narrative/politicsnlp/main/politics.
jpg" width = "50" 
height = "50" alt="logo" align=center />
</a><a href="https://pypi.org/project/cpanlp/">
<img src="https://raw.githubusercontent.com/accounting-intelligent-ai/cpanlp/main/cpanlp.png" width = "50" 
height = "50" alt="logo" align=center />
</a><a href="https://pypi.org/project/lawnlp/">
<img src="https://raw.githubusercontent.com/
python-narrative/lawnlp/main/law.
jpg" width = "50" 
height = "50" alt="logo" align=center />

<br/>
<a >
<img src="https://raw.githubusercontent.com/
python-narrative/economynlp/main/economynlp.jpg" width = 
"220" height = "100" alt="logo" align=center />
</a>

## Communicate effectively within a common Economic framework
  




For detailed installation instructions, see the
[documentation](https://economynlp.com/documentation).
```python
pip install economynlp
import economynlp as p
```

## Features

Information Asymmetry
```python
info = p.AsymmetricInformation(sender="investor", receiver="company_A", message="I am very interested in investing in your business", hidden_information="I have a limited budget")
info.get_advantage()
```

## Module:

|  Module   | Content  |
|  :----:  | :----:  |
| **Abnormal**  | `Winner Curse`，`Bubble`|
| **Cognitive**  | `BlackSwan`，`Grey Rhino`，`Herd Behavior` ，`Invisible Hand`，`Revolving Door` |
| **Culture**  | `Entrepreneurship`，`Craftsmanship`，`Business Philosophy` |
| **Environment**  | `Economic Environment`，`Industry Environment`，`Credit Environment`，`Market Environment`|
| **Information**  | `Signal`，`Speculative Information`，`Asymmetric Information` |
| **Market**  | `Commodity`，`Goods`，`Market`|
| **Structure**  | `Monopoly`，`Oligopoly`，`PerfectlyCompetitive`|
| **System** |  `Digital Economy` ，`Physical Economy` ，`Market Economy`，`Planned  Economy` |


Check out: https://cpanlp.com

==> economynlp-0.0.5.tar.gz: economynlp-0.0.5/README.md <==
# Python Narrative packages

<img src="https://raw.githubusercontent.com/python-narrative/politicsnlp/main/politics.jpg" width = "50" height = "50" alt="logo" align=center />
</a><a href="https://pypi.org/project/cpanlp/">
<img src="https://raw.githubusercontent.com/accounting-intelligent-ai/cpanlp/main/cpanlp.png" width = "50" height = "50" alt="logo" align=center />
</a><a href="https://pypi.org/project/lawnlp/"><img src="https://raw.githubusercontent.com/python-narrative/lawnlp/main/law.jpg" width = "50" height = "50" alt="logo" align=center />

<br/>
<a >
<img src="https://raw.githubusercontent.com/python-narrative/economynlp/main/economynlp.jpg" width = "220" height = "100" alt="logo" align=center />
</a>

## Communicate effectively within a common Economic framework
  
For detailed installation instructions, see the
[documentation](https://economynlp.com/documentation).
```python
pip install economynlp
import economynlp as p
```

## Features

Information Asymmetry
```python
info = p.AsymmetricInformation(sender="investor", receiver="company_A", message="I am very interested in investing in your business", hidden_information="I have a limited budget")
info.get_advantage()
```

## Module:

|  Module   | Content  |
|  :----:  | :----:  |
| **Abnormal**  | `Winner Curse`，`Bubble`|
| **Cognitive**  | `BlackSwan`，`Grey Rhino`，`Herd Behavior` ，`Invisible Hand`，`Revolving Door` |
| **Culture**  | `Entrepreneurship`，`Craftsmanship`，`Business Philosophy` |
| **Environment**  | `Economic Environment`，`Industry Environment`，`Credit Environment`，`Market Environment`|
| **Information**  | `Signal`，`Speculative Information`，`Asymmetric Information` |
| **Market**  | `Commodity`，`Goods`，`Market`|
| **Structure**  | `Monopoly`，`Oligopoly`，`PerfectlyCompetitive`|
| **System** |  `Digital Economy` ，`Physical Economy` ，`Market Economy`，`Planned  Economy` |


Check out: https://cpanlp.com
